@@ -22,6 +22,7 @@ from .core_objects import (
     BaseSummary,
     BaseTranscript,
     ExtractJob,
+    InMemorySource,
     ListJobs,
     ListSummaries,
     ListTranscripts,
@@ -93,7 +94,7 @@ def get_stats(
 
 @no_type_check
 def start_extract(
-    source_object: BaseSource,
+    source_object: Union[BaseSource, InMemorySource],
     display_name: str,
     ephemeral_data: Optional[bool] = False,
     only_api: Optional[bool] = True,
@@ -112,7 +113,7 @@ def start_extract(
 
     Parameters
     ----------
-    source_object : BaseSource
+    source_object : BaseSource or InMemorySource
         The source object to use for the extraction job.
     display_name : str
         The display name of the extraction job. This is useful for retrieving the job later.
@@ -153,7 +154,7 @@ def start_extract(
 
 @no_type_check
 def start_summary(
-    source_object: BaseSource,
+    source_object: Union[BaseSource, InMemorySource],
     display_name: str,
     summary_type: str,
     ephemeral_data: bool = False,
@@ -170,7 +171,7 @@ def start_summary(
 
     Parameters
     ----------
-    source_object : BaseSource
+    source_object : BaseSource or InMemorySource
         The source object to summarize.
     display_name : str
         The display name of the summary. This is useful for retrieving the job later.
