@@ -34,6 +34,7 @@ from .core_objects import (
     BaseTranscript,
     ConclusionSummary,
     ExtractJob,
+    InMemorySource,
     JobSettings,
     ListJobs,
     ListSummaries,
@@ -138,7 +139,7 @@ class Client:
 
     def start_extract(  # noqa: C901
         self,
-        source_object: BaseSource,
+        source_object: Union[BaseSource, InMemorySource],
         display_name: str,
         ephemeral_data: Optional[bool] = False,
         only_api: Optional[bool] = True,
@@ -158,7 +159,10 @@ class Client:
                 You must specify a valid list of pipelines. Available pipelines are: {", ".join(EXTRACT_PIPELINES)}.
             """
             )
-        if isinstance(source_object, BaseSource) is False:
+        if (
+            isinstance(source_object, BaseSource) is False
+            and isinstance(source_object, InMemorySource) is False
+        ):
             raise ValueError(
                 """
                 You must specify a valid source object for the extraction job.
@@ -171,7 +175,10 @@ class Client:
             raise ValueError(
                 f"Invalid source: {source}. Source must be one of {SOURCE_OBJECT_MAPPING.keys()}"
             )
-        if source_object.__class__.__name__ != SOURCE_OBJECT_MAPPING[source]:
+        if (
+            source_object.__class__.__name__ != SOURCE_OBJECT_MAPPING[source]
+            and source_object.__class__.__name__ != "InMemorySource"
+        ):
             raise ValueError(
                 f"""
                 Invalid source object: {source_object}. Source object must be of type {SOURCE_OBJECT_MAPPING[source]},
@@ -240,7 +247,7 @@ class Client:
 
     def start_summary(  # noqa: C901
         self,
-        source_object: BaseSource,
+        source_object: Union[BaseSource, InMemorySource],
         display_name: str,
         summary_type: str,
         ephemeral_data: Optional[bool] = False,
@@ -286,7 +293,10 @@ class Client:
             """
             )
 
-        if isinstance(source_object, BaseSource) is False:
+        if (
+            isinstance(source_object, BaseSource) is False
+            and isinstance(source_object, InMemorySource) is False
+        ):
             raise ValueError(
                 """
                 You must specify a valid source object to summarize.
@@ -316,7 +326,10 @@ class Client:
             raise ValueError(
                 f"Invalid source: {source}. Source must be one of {SOURCE_OBJECT_MAPPING.keys()}"
             )
-        if source_object.__class__.__name__ != SOURCE_OBJECT_MAPPING[source]:
+        if (
+            source_object.__class__.__name__ != SOURCE_OBJECT_MAPPING[source]
+            and source_object.__class__.__name__ != "InMemorySource"
+        ):
             raise ValueError(
                 f"""
                 Invalid source object: {source_object}. Source object must be of type {SOURCE_OBJECT_MAPPING[source]},
